@@ -19,6 +19,15 @@
 #ifndef ANDROID_DEFAULT
 # define ANDROID_DEFAULT 0
 #endif
+#ifndef TARGET_DEFAULT_ASYNC_UNWIND_TABLES
+# define TARGET_DEFAULT_ASYNC_UNWIND_TABLES 1
+#endif
+#ifndef TARGET_FIX_ERR_A53_835769_DEFAULT
+# define TARGET_FIX_ERR_A53_835769_DEFAULT 1
+#endif
+#ifndef TARGET_FIX_ERR_A53_843419_DEFAULT
+# define TARGET_FIX_ERR_A53_843419_DEFAULT 1
+#endif
 #ifdef IN_GCC
 # include "options.h"
 # include "insn-constants.h"
@@ -39,8 +48,5 @@
 #if defined IN_GCC && !defined GENERATOR_FILE
 # include "insn-modes.h"
 #endif
-#if defined IN_GCC && defined GENERATOR_FILE && !defined BITS_PER_UNIT
-#include "machmode.h"
-#endif
 # include "defaults.h"
 #endif /* GCC_TM_H */
